# xTractr

### Purpose
xTractr is a repository of all extraction-related functions that I've had to use for varying projects - generalized to be able to be useful across any range of tasks. Some of the extraction mechanisms are genuinely involved and are useful, others are simply 2 line functions meant to more clearly represent abstractions provided by packages and services like Python-Docx, Selenium, and AWS. The goal of xTractr is to make a variety of disparate 'extraction-related' tasks much more human-readable and simpler to reference in an IDE with autocomplete than having to lookup a method everytime you want to do something. 

### Future Work
Right now, xTractr is kind of barebones - I plan on diversifying some of its functionality and continuing to experiment with effective ways to communicate the purpose of varying packages. Let me know if there's a type of job that I missed as I expand its scope. 
